@@ -7,18 +7,18 @@
 
 source("counterstrike.R")
 equalstrengths <- rep(0.1, 9)
-datapoint <- loglik(H,indep(maxp(H))) - loglik(H,equalstrengths)
+datapoint <- loglik(indep(maxp(counterstrike)),counterstrike) - loglik(equalstrengths,counterstrike)
 
 
-n <- 1000  # takes about 5 minutes for n=1000 trials
+n <- 10  # takes about 5 minutes for n=1000 trials
 distrib <- rep(0,n)
 for(i in seq_len(n)){
   Hrand <- hyper2(pnames=c(team1,team2))
   for(jj in 1:6){
     pp <- rdeath(team1,team2)
-    Hrand <- Hrand + counterstrike(team1,team2, pp)
+    Hrand <- Hrand + counterstrike_maker(team1,team2, pp)
   }
-  distrib[i] <- loglik(Hrand,indep(maxp(Hrand))) - loglik(Hrand,equalstrengths)
+  distrib[i] <- loglik(indep(maxp(Hrand)),Hrand) - loglik(equalstrengths,Hrand)
   print(i)
 }
 
